@@ -11,6 +11,8 @@
 
 #include <memory>
 
+class QToolBar;
+
 namespace MimeTreeParser
 {
 namespace Widgets
@@ -29,6 +31,8 @@ public:
     MessageViewerDialog(const QString &fileName, QWidget *parent = nullptr);
     ~MessageViewerDialog() override;
 
+    QToolBar *toolBar() const;
+
     QList<KMime::Message::Ptr> messages() const;
 
 private:
